public class ClasificadorPaltas {
  private MedidorPorFirmeza mpf;
  private MedidorPorAceite mpa;
  private ControlDeCompuertas cdc;
  private Canasta[] baskets;
  
  public ClasificadorPaltas( int basketNum){
    setFruitParameters();
    mpf = new MedidorPorFirmeza();
    mpf.calibrate(Palta.MAX_TIME2RIPE, Palta.MIN_TIME2RIPE,
                  Palta.MAX_FIRMNESS, Palta.MIN_FIRMNESS);    
    mpa = new MedidorPorAceite();
    mpa.calibrate(Palta.MAX_TIME2RIPE, Palta.MIN_TIME2RIPE,
                  Palta.MIN_OIL_PERCENTAGE, Palta.MAX_OIL_PERCENTAGE);
    
    cdc =  new ControlDeCompuertas(basketNum, Palta.MIN_TIME2RIPE,
                                   Palta.MAX_TIME2RIPE);
    baskets = new Canasta[basketNum];
    for (int j=0; j<baskets.length ; j++)
      baskets[j]=new Canasta();
  }
  
  public void classify(Palta p) {
    do        
      cdc.setMeasurements(mpa.measure(p), mpf.measure(p));
    while (!cdc.withinTolerance());   // medimos mientras error no es aceptable
    baskets[cdc.getBasketIndex()].keepFruit(cdc.getAverage());
  }
  
  private void setFruitParameters(){
    Palta.MAX_TIME2RIPE=288;
    Palta.MIN_TIME2RIPE=0;
    Palta.MAX_OIL_PERCENTAGE=11;
    Palta.MIN_OIL_PERCENTAGE=5;
    Palta.MAX_FIRMNESS=140;
    Palta.MIN_FIRMNESS=20;
  }
  
  public void printBaskets(){
    System.out.println("Clasificación de Paltas:");
    for (int j=0; j<baskets.length ; j++)
      System.out.println("Canasto "+j+" contiene "+baskets[j].getCount()+
                         " Paltas con maduración entre "+cdc.getMinLimit(j)+
                         " y "+cdc.getMinLimit(j+1)+" horas y promedio de "+
                         baskets[j].getAverage()+" horas");  
  }
}
