public class ClasificadorTomates {
  private MedidorPorFirmeza mpf;
  private MedidorPorColor mpc;
  private ControlDeCompuertas cdc;
  private Canasta[] baskets;
  
  public ClasificadorTomates( int basketNum){
    setFruitParameters();
    mpf = new MedidorPorFirmeza();
    mpf.calibrate(Tomate.MAX_TIME2RIPE, Tomate.MIN_TIME2RIPE,
                  Tomate.MAX_FIRMNESS, Tomate.MIN_FIRMNESS);    
    mpc = new MedidorPorColor();
    mpc.calibrate(Tomate.MAX_TIME2RIPE, Tomate.MIN_TIME2RIPE,
                  Tomate.MIN_COLOR, Tomate.MAX_COLOR);
    cdc =  new ControlDeCompuertas(basketNum, Tomate.MIN_TIME2RIPE,
                                   Tomate.MAX_TIME2RIPE);
    baskets = new Canasta[basketNum];
    for (int j=0; j<baskets.length ; j++)
      baskets[j]=new Canasta();
  }
  
  public void classify(Tomate p) {
    do        
      cdc.setMeasurements(mpc.measure(p),mpf.measure(p));
    while (!cdc.withinTolerance());   // medimos miestras error no es aceptable
    baskets[cdc.getBasketIndex()].keepFruit(cdc.getAverage());
  }
  
  private void setFruitParameters(){
    Tomate.MAX_TIME2RIPE=144;
    Tomate.MIN_TIME2RIPE=0;
    Tomate.MAX_COLOR=240;
    Tomate.MIN_COLOR=40;
    Tomate.MAX_FIRMNESS=80;
    Tomate.MIN_FIRMNESS=10;
  }
  
  public void printBaskets(){
    System.out.println("Clasificación de Tomates:");
    for (int j=0; j<baskets.length ; j++)
      System.out.println("Canasto "+j+" contiene "+baskets[j].getCount()+
                         " Tomates con maduración entre "+cdc.getMinLimit(j)+
                         " y "+cdc.getMinLimit(j+1)+" horas y promedio de "+
                         baskets[j].getAverage()+" horas");  
  }
}
